@@ -25,7 +25,6 @@ from typing import Union
 
 import pinocchio as pin
 
-
 PinocchioJoint = Union[
     pin.JointModelRX,
     pin.JointModelRY,
@@ -58,15 +57,17 @@ def load_robot_description(
     """
     module = import_module(f"robot_descriptions.{description_name}")
 
+    package_dirs = [
+        module.PACKAGE_PATH,
+        module.REPOSITORY_PATH,
+        os.path.dirname(module.PACKAGE_PATH),
+        os.path.dirname(module.REPOSITORY_PATH),
+        os.path.dirname(module.URDF_PATH),  # e.g. laikago_description
+    ]
+
     robot = pin.RobotWrapper.BuildFromURDF(
         filename=module.URDF_PATH,
-        package_dirs=[
-            module.MESHES_PATH,
-            module.PACKAGE_PATH,
-            module.REPOSITORY_PATH,
-            os.path.dirname(module.PACKAGE_PATH),
-            os.path.dirname(module.REPOSITORY_PATH),
-        ],
+        package_dirs=package_dirs,
         root_joint=root_joint_type(),
     )
 
